# coding: utf-8

# flake8: noqa

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "3.54.3+ai.plus"

# import apis into sdk package
from iblai.api.media_resources_api import MediaResourcesApi
from iblai.api.ai_account_api import AiAccountApi
from iblai.api.ai_analytics_api import AiAnalyticsApi
from iblai.api.ai_bot_api import AiBotApi
from iblai.api.ai_finetuning_api import AiFinetuningApi
from iblai.api.ai_index_api import AiIndexApi
from iblai.api.ai_marketing_api import AiMarketingApi
from iblai.api.ai_media_api import AiMediaApi
from iblai.api.ai_mentor_api import AiMentorApi
from iblai.api.ai_prompt_api import AiPromptApi
from iblai.api.analytics_api import AnalyticsApi
from iblai.api.audience_api import AudienceApi
from iblai.api.career_api import CareerApi
from iblai.api.catalog_api import CatalogApi
from iblai.api.core_api import CoreApi
from iblai.api.credentials_api import CredentialsApi
from iblai.api.departments_api import DepartmentsApi
from iblai.api.engagement_api import EngagementApi
from iblai.api.features_api import FeaturesApi
from iblai.api.finance_api import FinanceApi
from iblai.api.notification_api import NotificationApi
from iblai.api.notification_builder_api import NotificationBuilderApi
from iblai.api.orgs_api import OrgsApi
from iblai.api.overview_api import OverviewApi
from iblai.api.performance_api import PerformanceApi
from iblai.api.perlearner_api import PerlearnerApi
from iblai.api.platform_api import PlatformApi
from iblai.api.provider_association_api import ProviderAssociationApi
from iblai.api.providers_api import ProvidersApi
from iblai.api.provision_api import ProvisionApi
from iblai.api.recommendations_api import RecommendationsApi
from iblai.api.reports_api import ReportsApi
from iblai.api.roles_api import RolesApi
from iblai.api.search_api import SearchApi
from iblai.api.service_api import ServiceApi
from iblai.api.skills_api import SkillsApi
from iblai.api.user_groups_api import UserGroupsApi

# import ApiClient
from iblai.api_response import ApiResponse
from iblai.api_client import ApiClient
from iblai.configuration import Configuration
from iblai.exceptions import OpenApiException
from iblai.exceptions import ApiTypeError
from iblai.exceptions import ApiValueError
from iblai.exceptions import ApiKeyError
from iblai.exceptions import ApiAttributeError
from iblai.exceptions import ApiException

# import models into sdk package
from iblai.models.ai_generated_image import AIGeneratedImage
from iblai.models.ai_user_profile_memory_relation import AIUserProfileMemoryRelation
from iblai.models.ai_user_profile_request import AIUserProfileRequest
from iblai.models.api_token_cost import APITokenCost
from iblai.models.aws_tenant_launch_request import AWSTenantLaunchRequest
from iblai.models.acceptance_enum import AcceptanceEnum
from iblai.models.access_enum import AccessEnum
from iblai.models.activate_user_free_trial import ActivateUserFreeTrial
from iblai.models.active_users_data import ActiveUsersData
from iblai.models.active_users_list import ActiveUsersList
from iblai.models.active_users_per_course import ActiveUsersPerCourse
from iblai.models.active_users_per_course_data import ActiveUsersPerCourseData
from iblai.models.activity_api import ActivityAPI
from iblai.models.activity_data import ActivityData
from iblai.models.ai_account_orgs_use_default_llm_key_create200_response import AiAccountOrgsUseDefaultLlmKeyCreate200Response
from iblai.models.ai_account_orgs_users_free_trial_retrieve200_response import AiAccountOrgsUsersFreeTrialRetrieve200Response
from iblai.models.align_mentor_bubble_enum import AlignMentorBubbleEnum
from iblai.models.analytics_overview import AnalyticsOverview
from iblai.models.answer import Answer
from iblai.models.app import App
from iblai.models.apple_subscription_status_request import AppleSubscriptionStatusRequest
from iblai.models.apple_subscription_status_view import AppleSubscriptionStatusView
from iblai.models.apple_verify_transaction_id import AppleVerifyTransactionId
from iblai.models.assertion import Assertion
from iblai.models.associate_account_response import AssociateAccountResponse
from iblai.models.associate_apple_account import AssociateAppleAccount
from iblai.models.assumed_knowledge import AssumedKnowledge
from iblai.models.assumed_knowledge_level import AssumedKnowledgeLevel
from iblai.models.audio_to_text_request import AudioToTextRequest
from iblai.models.audio_to_text_response import AudioToTextResponse
from iblai.models.auth_token import AuthToken
from iblai.models.average import Average
from iblai.models.average_data import AverageData
from iblai.models.average_overtime import AverageOvertime
from iblai.models.avg_course_grade_with_cutoff import AvgCourseGradeWithCutoff
from iblai.models.avg_course_grade_with_cutoff_data import AvgCourseGradeWithCutoffData
from iblai.models.base_error_response import BaseErrorResponse
from iblai.models.base_response import BaseResponse
from iblai.models.blank_course_invitation_create import BlankCourseInvitationCreate
from iblai.models.blank_enum import BlankEnum
from iblai.models.blank_platform_invitation_create import BlankPlatformInvitationCreate
from iblai.models.blank_program_invitation_create import BlankProgramInvitationCreate
from iblai.models.block_skill_point_info_request import BlockSkillPointInfoRequest
from iblai.models.bot import Bot
from iblai.models.bot_command import BotCommand
from iblai.models.bot_create import BotCreate
from iblai.models.bulk_course_invitation_create import BulkCourseInvitationCreate
from iblai.models.bulk_course_invitation_response import BulkCourseInvitationResponse
from iblai.models.bulk_create_assertion import BulkCreateAssertion
from iblai.models.bulk_platform_invitation_create import BulkPlatformInvitationCreate
from iblai.models.bulk_platform_invitation_response import BulkPlatformInvitationResponse
from iblai.models.bulk_program_invitation_create import BulkProgramInvitationCreate
from iblai.models.bulk_program_invitation_response import BulkProgramInvitationResponse
from iblai.models.bulk_suggestion_response import BulkSuggestionResponse
from iblai.models.call_authentication_request import CallAuthenticationRequest
from iblai.models.call_authentication_response import CallAuthenticationResponse
from iblai.models.call_configuration import CallConfiguration
from iblai.models.call_configuration_mode_enum import CallConfigurationModeEnum
from iblai.models.campaign_enablement import CampaignEnablement
from iblai.models.campaign_exclusion import CampaignExclusion
from iblai.models.catalog_auto_increment_response import CatalogAutoIncrementResponse
from iblai.models.catalog_auto_increment_update_request import CatalogAutoIncrementUpdateRequest
from iblai.models.celery_heartbeat import CeleryHeartbeat
from iblai.models.celery_heartbeat_fail import CeleryHeartbeatFail
from iblai.models.celery_heartbeat_fail_status_enum import CeleryHeartbeatFailStatusEnum
from iblai.models.celery_heartbeat_status_enum import CeleryHeartbeatStatusEnum
from iblai.models.chat_history import ChatHistory
from iblai.models.chat_history_filter_data import ChatHistoryFilterData
from iblai.models.chat_history_filter_user import ChatHistoryFilterUser
from iblai.models.chat_history_item import ChatHistoryItem
from iblai.models.chat_history_session_id import ChatHistorySessionId
from iblai.models.chat_session_request import ChatSessionRequest
from iblai.models.chat_session_response import ChatSessionResponse
from iblai.models.check_document_training_status import CheckDocumentTrainingStatus
from iblai.models.company import Company
from iblai.models.component_block import ComponentBlock
from iblai.models.component_block_type_enum import ComponentBlockTypeEnum
from iblai.models.context_response import ContextResponse
from iblai.models.conversation_message import ConversationMessage
from iblai.models.conversation_rating import ConversationRating
from iblai.models.conversation_summary import ConversationSummary
from iblai.models.conversation_volume import ConversationVolume
from iblai.models.conversations import Conversations
from iblai.models.cost import Cost
from iblai.models.cost_per_tenant import CostPerTenant
from iblai.models.count import Count
from iblai.models.count_data import CountData
from iblai.models.course import Course
from iblai.models.course_access_request_create import CourseAccessRequestCreate
from iblai.models.course_access_request_detail import CourseAccessRequestDetail
from iblai.models.course_access_request_status_response import CourseAccessRequestStatusResponse
from iblai.models.course_access_request_update import CourseAccessRequestUpdate
from iblai.models.course_completion import CourseCompletion
from iblai.models.course_completion_per_course import CourseCompletionPerCourse
from iblai.models.course_completion_per_course_data import CourseCompletionPerCourseData
from iblai.models.course_completion_summary_data_overtime import CourseCompletionSummaryDataOvertime
from iblai.models.course_completion_summary_overtime import CourseCompletionSummaryOvertime
from iblai.models.course_create_update import CourseCreateUpdate
from iblai.models.course_creation_task import CourseCreationTask
from iblai.models.course_creation_task_file import CourseCreationTaskFile
from iblai.models.course_creation_task_status_enum import CourseCreationTaskStatusEnum
from iblai.models.course_delete_response import CourseDeleteResponse
from iblai.models.course_enrollment_search_response import CourseEnrollmentSearchResponse
from iblai.models.course_grade_detail_block import CourseGradeDetailBlock
from iblai.models.course_grade_detail_sub_section import CourseGradeDetailSubSection
from iblai.models.course_grade_summary import CourseGradeSummary
from iblai.models.course_grade_summary_data import CourseGradeSummaryData
from iblai.models.course_grading_detail import CourseGradingDetail
from iblai.models.course_grading_detail_data import CourseGradingDetailData
from iblai.models.course_group_suggestion_create import CourseGroupSuggestionCreate
from iblai.models.course_group_suggestion_detail import CourseGroupSuggestionDetail
from iblai.models.course_invitation_create import CourseInvitationCreate
from iblai.models.course_invitation_detail import CourseInvitationDetail
from iblai.models.course_invitation_redemption import CourseInvitationRedemption
from iblai.models.course_license_assignment_create import CourseLicenseAssignmentCreate
from iblai.models.course_license_assignment_detail import CourseLicenseAssignmentDetail
from iblai.models.course_license_create import CourseLicenseCreate
from iblai.models.course_license_detail import CourseLicenseDetail
from iblai.models.course_license_group_assignment_create import CourseLicenseGroupAssignmentCreate
from iblai.models.course_license_group_assignment_detail import CourseLicenseGroupAssignmentDetail
from iblai.models.course_license_update import CourseLicenseUpdate
from iblai.models.course_metadata_search_request import CourseMetadataSearchRequest
from iblai.models.course_metadata_update_request import CourseMetadataUpdateRequest
from iblai.models.course_point import CoursePoint
from iblai.models.course_review_info_response import CourseReviewInfoResponse
from iblai.models.course_review_paginated_response import CourseReviewPaginatedResponse
from iblai.models.course_review_request import CourseReviewRequest
from iblai.models.course_review_response import CourseReviewResponse
from iblai.models.course_skill import CourseSkill
from iblai.models.course_skill_point_info_request import CourseSkillPointInfoRequest
from iblai.models.course_suggestion_bulk_create import CourseSuggestionBulkCreate
from iblai.models.course_suggestion_create import CourseSuggestionCreate
from iblai.models.course_suggestion_detail import CourseSuggestionDetail
from iblai.models.credential import Credential
from iblai.models.credential_request import CredentialRequest
from iblai.models.crontab_schedule import CrontabSchedule
from iblai.models.custom_instruction_response import CustomInstructionResponse
from iblai.models.data_set import DataSet
from iblai.models.data_set_create import DataSetCreate
from iblai.models.data_set_platform_value import DataSetPlatformValue
from iblai.models.data_set_status_enum import DataSetStatusEnum
from iblai.models.date_range import DateRange
from iblai.models.desired_role import DesiredRole
from iblai.models.desired_role_create_update_request import DesiredRoleCreateUpdateRequest
from iblai.models.desired_skill import DesiredSkill
from iblai.models.desired_skill_create_update_request import DesiredSkillCreateUpdateRequest
from iblai.models.detailed_grade_subsection import DetailedGradeSubsection
from iblai.models.detailed_grade_view import DetailedGradeView
from iblai.models.detailed_grade_view_data import DetailedGradeViewData
from iblai.models.discord_config import DiscordConfig
from iblai.models.discord_user_config import DiscordUserConfig
from iblai.models.discord_webhook import DiscordWebhook
from iblai.models.document import Document
from iblai.models.document_facet import DocumentFacet
from iblai.models.document_search_response import DocumentSearchResponse
from iblai.models.document_settings_response import DocumentSettingsResponse
from iblai.models.education import Education
from iblai.models.edx_course import EdxCourse
from iblai.models.edx_signal_receiver_request import EdxSignalReceiverRequest
from iblai.models.elevenlabs_custom_voice import ElevenlabsCustomVoice
from iblai.models.elevenlabs_custom_voice_response import ElevenlabsCustomVoiceResponse
from iblai.models.email_prompt_detail import EmailPromptDetail
from iblai.models.email_prompt_list import EmailPromptList
from iblai.models.email_prompt_summary import EmailPromptSummary
from iblai.models.engagement_per_course import EngagementPerCourse
from iblai.models.engagement_per_course_data import EngagementPerCourseData
from iblai.models.enrollments import Enrollments
from iblai.models.enrollments_data import EnrollmentsData
from iblai.models.enrollments_per_user import EnrollmentsPerUser
from iblai.models.enrollments_per_user_data import EnrollmentsPerUserData
from iblai.models.error_response import ErrorResponse
from iblai.models.experience import Experience
from iblai.models.float_over_time import FloatOverTime
from iblai.models.free_usage_count import FreeUsageCount
from iblai.models.full_course import FullCourse
from iblai.models.gcp_tenant_launch_request import GCPTenantLaunchRequest
from iblai.models.global_catalog_search_response import GlobalCatalogSearchResponse
from iblai.models.google_pay_account_response import GooglePayAccountResponse
from iblai.models.google_pay_account_response_status_enum import GooglePayAccountResponseStatusEnum
from iblai.models.google_pay_verify_token import GooglePayVerifyToken
from iblai.models.grading_per_user import GradingPerUser
from iblai.models.grading_per_user_data import GradingPerUserData
from iblai.models.greeting_method_enum import GreetingMethodEnum
from iblai.models.group_list import GroupList
from iblai.models.group_list_data import GroupListData
from iblai.models.guided_prompts_response import GuidedPromptsResponse
from iblai.models.heygen_marketing_video_detail import HeygenMarketingVideoDetail
from iblai.models.heygen_marketing_video_list import HeygenMarketingVideoList
from iblai.models.heygen_template_request import HeygenTemplateRequest
from iblai.models.heygen_template_response_single import HeygenTemplateResponseSingle
from iblai.models.heygen_video_detail import HeygenVideoDetail
from iblai.models.heygen_video_request import HeygenVideoRequest
from iblai.models.iblai_platform_meta import IBLAIPlatformMeta
from iblai.models.iblai_platform_meta_request import IBLAIPlatformMetaRequest
from iblai.models.iblai_platform_meta_update_request import IBLAIPlatformMetaUpdateRequest
from iblai.models.image_upload import ImageUpload
from iblai.models.input_question import InputQuestion
from iblai.models.institution import Institution
from iblai.models.institution_type_enum import InstitutionTypeEnum
from iblai.models.integration_credential import IntegrationCredential
from iblai.models.intial_question_answer import IntialQuestionAnswer
from iblai.models.issuer import Issuer
from iblai.models.issuer_authority import IssuerAuthority
from iblai.models.item_type_enum import ItemTypeEnum
from iblai.models.job_run import JobRun
from iblai.models.kind_enum import KindEnum
from iblai.models.llm_credential_request import LLMCredentialRequest
from iblai.models.llm_credential_response import LLMCredentialResponse
from iblai.models.llm_model_for_tenant import LLMModelForTenant
from iblai.models.llm_question import LLMQuestion
from iblai.models.llm_response import LLMResponse
from iblai.models.llm_traces_list_response import LLMTracesListResponse
from iblai.models.languages_view import LanguagesView
from iblai.models.launcher_view_post_request import LauncherViewPostRequest
from iblai.models.learner_information_api import LearnerInformationAPI
from iblai.models.learner_information_api_data import LearnerInformationAPIData
from iblai.models.link_course_request import LinkCourseRequest
from iblai.models.link_course_response import LinkCourseResponse
from iblai.models.llm_provider_enum import LlmProviderEnum
from iblai.models.lti_key import LtiKey
from iblai.models.lti_launch_gate import LtiLaunchGate
from iblai.models.lti_tool import LtiTool
from iblai.models.mcp_server import MCPServer
from iblai.models.manager_auth_token import ManagerAuthToken
from iblai.models.mark_all_read_request import MarkAllReadRequest
from iblai.models.mark_all_read_response import MarkAllReadResponse
from iblai.models.media_resource import MediaResource
from iblai.models.media_type_enum import MediaTypeEnum
from iblai.models.memory_component_data import MemoryComponentData
from iblai.models.memory_component_memory import MemoryComponentMemory
from iblai.models.memory_component_memory_detail import MemoryComponentMemoryDetail
from iblai.models.memory_component_response import MemoryComponentResponse
from iblai.models.memory_progress import MemoryProgress
from iblai.models.memory_status_request_view import MemoryStatusRequestView
from iblai.models.memory_status_view import MemoryStatusView
from iblai.models.mentor import Mentor
from iblai.models.mentor_audience import MentorAudience
from iblai.models.mentor_category import MentorCategory
from iblai.models.mentor_category_create import MentorCategoryCreate
from iblai.models.mentor_category_group import MentorCategoryGroup
from iblai.models.mentor_category_group_create import MentorCategoryGroupCreate
from iblai.models.mentor_create import MentorCreate
from iblai.models.mentor_custom_voice import MentorCustomVoice
from iblai.models.mentor_custom_voice_response import MentorCustomVoiceResponse
from iblai.models.mentor_data import MentorData
from iblai.models.mentor_detail_analytics import MentorDetailAnalytics
from iblai.models.mentor_eval import MentorEval
from iblai.models.mentor_eval_question import MentorEvalQuestion
from iblai.models.mentor_eval_question_request import MentorEvalQuestionRequest
from iblai.models.mentor_eval_report import MentorEvalReport
from iblai.models.mentor_eval_request import MentorEvalRequest
from iblai.models.mentor_facet import MentorFacet
from iblai.models.mentor_fork import MentorFork
from iblai.models.mentor_from_template_request import MentorFromTemplateRequest
from iblai.models.mentor_from_template_with_setting_request import MentorFromTemplateWithSettingRequest
from iblai.models.mentor_memory_settings_request import MentorMemorySettingsRequest
from iblai.models.mentor_memory_settings_response import MentorMemorySettingsResponse
from iblai.models.mentor_metadata import MentorMetadata
from iblai.models.mentor_scenario import MentorScenario
from iblai.models.mentor_scenario_prompt import MentorScenarioPrompt
from iblai.models.mentor_search_response import MentorSearchResponse
from iblai.models.mentor_session import MentorSession
from iblai.models.mentor_settings import MentorSettings
from iblai.models.mentor_settings_mentor_visibility import MentorSettingsMentorVisibility
from iblai.models.mentor_settings_public import MentorSettingsPublic
from iblai.models.mentor_settings_request import MentorSettingsRequest
from iblai.models.mentor_visibility_enum import MentorVisibilityEnum
from iblai.models.mentor_wizard import MentorWizard
from iblai.models.message_statistics import MessageStatistics
from iblai.models.message_status import MessageStatus
from iblai.models.message_view import MessageView
from iblai.models.message_view_request import MessageViewRequest
from iblai.models.message_view_updat_response import MessageViewUpdatResponse
from iblai.models.metadata import Metadata
from iblai.models.metric_change import MetricChange
from iblai.models.model_cost import ModelCost
from iblai.models.moderation_log import ModerationLog
from iblai.models.net_revenue_over_time import NetRevenueOverTime
from iblai.models.new_per_learner_list import NewPerLearnerList
from iblai.models.new_per_learner_list_data import NewPerLearnerListData
from iblai.models.no_chat_messages_found import NoChatMessagesFound
from iblai.models.notification import Notification
from iblai.models.notification_count import NotificationCount
from iblai.models.notification_preview import NotificationPreview
from iblai.models.notification_source import NotificationSource
from iblai.models.notification_source_type_enum import NotificationSourceTypeEnum
from iblai.models.notification_status_enum import NotificationStatusEnum
from iblai.models.notification_template_data import NotificationTemplateData
from iblai.models.notification_v1_campaigns_unsubscribe_retrieve200_response import NotificationV1CampaignsUnsubscribeRetrieve200Response
from iblai.models.null_enum import NullEnum
from iblai.models.onboarding_status_update import OnboardingStatusUpdate
from iblai.models.order import Order
from iblai.models.over_time import OverTime
from iblai.models.over_time_with_total import OverTimeWithTotal
from iblai.models.overtime_meta import OvertimeMeta
from iblai.models.overtime_with_change_info import OvertimeWithChangeInfo
from iblai.models.page_content import PageContent
from iblai.models.paginated_ai_generated_image_list import PaginatedAIGeneratedImageList
from iblai.models.paginated_assertions_response import PaginatedAssertionsResponse
from iblai.models.paginated_conversations_list import PaginatedConversationsList
from iblai.models.paginated_course_access_request import PaginatedCourseAccessRequest
from iblai.models.paginated_course_creation_task_file_list import PaginatedCourseCreationTaskFileList
from iblai.models.paginated_course_creation_task_list import PaginatedCourseCreationTaskList
from iblai.models.paginated_course_group_suggestion import PaginatedCourseGroupSuggestion
from iblai.models.paginated_course_invitation import PaginatedCourseInvitation
from iblai.models.paginated_course_license import PaginatedCourseLicense
from iblai.models.paginated_course_license_assignment import PaginatedCourseLicenseAssignment
from iblai.models.paginated_course_license_group_assignment import PaginatedCourseLicenseGroupAssignment
from iblai.models.paginated_course_suggestion import PaginatedCourseSuggestion
from iblai.models.paginated_data_set_list import PaginatedDataSetList
from iblai.models.paginated_edx_course_list import PaginatedEdxCourseList
from iblai.models.paginated_email_prompt_list_list import PaginatedEmailPromptListList
from iblai.models.paginated_heygen_marketing_video_list_list import PaginatedHeygenMarketingVideoListList
from iblai.models.paginated_heygen_template_response_single_list import PaginatedHeygenTemplateResponseSingleList
from iblai.models.paginated_job_run_list import PaginatedJobRunList
from iblai.models.paginated_mcp_server_list import PaginatedMCPServerList
from iblai.models.paginated_mentor_list import PaginatedMentorList
from iblai.models.paginated_moderation_log_list import PaginatedModerationLogList
from iblai.models.paginated_pathway_group_suggestion import PaginatedPathwayGroupSuggestion
from iblai.models.paginated_pathway_suggestion import PaginatedPathwaySuggestion
from iblai.models.paginated_periodic_agent_list import PaginatedPeriodicAgentList
from iblai.models.paginated_periodic_agent_log_list import PaginatedPeriodicAgentLogList
from iblai.models.paginated_platform_invitation import PaginatedPlatformInvitation
from iblai.models.paginated_platform_license import PaginatedPlatformLicense
from iblai.models.paginated_play_wright_script_list import PaginatedPlayWrightScriptList
from iblai.models.paginated_program_group_suggestion import PaginatedProgramGroupSuggestion
from iblai.models.paginated_program_invitation import PaginatedProgramInvitation
from iblai.models.paginated_program_license import PaginatedProgramLicense
from iblai.models.paginated_program_license_assignment import PaginatedProgramLicenseAssignment
from iblai.models.paginated_program_license_group_assignment import PaginatedProgramLicenseGroupAssignment
from iblai.models.paginated_program_suggestion import PaginatedProgramSuggestion
from iblai.models.paginated_rbac_group_list import PaginatedRbacGroupList
from iblai.models.paginated_rbac_policy_list import PaginatedRbacPolicyList
from iblai.models.paginated_rbac_role_list import PaginatedRbacRoleList
from iblai.models.paginated_retriever_document_embedding_list import PaginatedRetrieverDocumentEmbeddingList
from iblai.models.paginated_section_list import PaginatedSectionList
from iblai.models.paginated_skill import PaginatedSkill
from iblai.models.paginated_sub_section_list import PaginatedSubSectionList
from iblai.models.paginated_topic_statistics_response import PaginatedTopicStatisticsResponse
from iblai.models.paginated_training_list import PaginatedTrainingList
from iblai.models.paginated_unit_list import PaginatedUnitList
from iblai.models.paginated_user_app_list import PaginatedUserAppList
from iblai.models.paginated_user_edx_memory_list import PaginatedUserEdxMemoryList
from iblai.models.paginated_user_license import PaginatedUserLicense
from iblai.models.paginated_user_license_assignment import PaginatedUserLicenseAssignment
from iblai.models.paginated_user_license_group_assignment import PaginatedUserLicenseGroupAssignment
from iblai.models.paginated_voice_list import PaginatedVoiceList
from iblai.models.pagination import Pagination
from iblai.models.patched_bot_command import PatchedBotCommand
from iblai.models.patched_bot_create import PatchedBotCreate
from iblai.models.patched_call_configuration import PatchedCallConfiguration
from iblai.models.patched_conversations import PatchedConversations
from iblai.models.patched_course_creation_task_file import PatchedCourseCreationTaskFile
from iblai.models.patched_credential_request import PatchedCredentialRequest
from iblai.models.patched_data_set import PatchedDataSet
from iblai.models.patched_discord_config import PatchedDiscordConfig
from iblai.models.patched_discord_user_config import PatchedDiscordUserConfig
from iblai.models.patched_llm_credential_request import PatchedLLMCredentialRequest
from iblai.models.patched_mcp_server import PatchedMCPServer
from iblai.models.patched_media_resource import PatchedMediaResource
from iblai.models.patched_mentor_category_group_create import PatchedMentorCategoryGroupCreate
from iblai.models.patched_mentor_create import PatchedMentorCreate
from iblai.models.patched_notification import PatchedNotification
from iblai.models.patched_periodic_agent_create import PatchedPeriodicAgentCreate
from iblai.models.patched_platform_public_metadata import PatchedPlatformPublicMetadata
from iblai.models.patched_play_wright_script import PatchedPlayWrightScript
from iblai.models.patched_prompt import PatchedPrompt
from iblai.models.patched_prompt_prompt_visibility import PatchedPromptPromptVisibility
from iblai.models.patched_rbac_group import PatchedRbacGroup
from iblai.models.patched_rbac_policy import PatchedRbacPolicy
from iblai.models.patched_rbac_role import PatchedRbacRole
from iblai.models.patched_section import PatchedSection
from iblai.models.patched_skill_threshold import PatchedSkillThreshold
from iblai.models.patched_slack_config import PatchedSlackConfig
from iblai.models.patched_slack_user_config import PatchedSlackUserConfig
from iblai.models.patched_sub_section import PatchedSubSection
from iblai.models.patched_teams_config import PatchedTeamsConfig
from iblai.models.patched_training_create import PatchedTrainingCreate
from iblai.models.patched_unit import PatchedUnit
from iblai.models.patched_webex_config import PatchedWebexConfig
from iblai.models.patched_whatsapp_config import PatchedWhatsappConfig
from iblai.models.patched_whatsapp_user_config import PatchedWhatsappUserConfig
from iblai.models.pathway import Pathway
from iblai.models.pathway_completion_response import PathwayCompletionResponse
from iblai.models.pathway_create_update_request import PathwayCreateUpdateRequest
from iblai.models.pathway_delete_response import PathwayDeleteResponse
from iblai.models.pathway_enrollment import PathwayEnrollment
from iblai.models.pathway_enrollment_plus import PathwayEnrollmentPlus
from iblai.models.pathway_enrollment_request import PathwayEnrollmentRequest
from iblai.models.pathway_group_suggestion_create import PathwayGroupSuggestionCreate
from iblai.models.pathway_group_suggestion_detail import PathwayGroupSuggestionDetail
from iblai.models.pathway_self_enrollment_request import PathwaySelfEnrollmentRequest
from iblai.models.pathway_suggestion_bulk_create import PathwaySuggestionBulkCreate
from iblai.models.pathway_suggestion_create import PathwaySuggestionCreate
from iblai.models.pathway_suggestion_detail import PathwaySuggestionDetail
from iblai.models.per_learner_course_last_access_data import PerLearnerCourseLastAccessData
from iblai.models.per_learner_course_videos_watched import PerLearnerCourseVideosWatched
from iblai.models.per_learner_course_videos_watched_data import PerLearnerCourseVideosWatchedData
from iblai.models.per_learner_last_access import PerLearnerLastAccess
from iblai.models.per_learner_last_access_data import PerLearnerLastAccessData
from iblai.models.per_learner_time_spent_in_course_tree import PerLearnerTimeSpentInCourseTree
from iblai.models.performance_grades_per_course import PerformanceGradesPerCourse
from iblai.models.performance_grades_per_course_data import PerformanceGradesPerCourseData
from iblai.models.periodic_agent import PeriodicAgent
from iblai.models.periodic_agent_create import PeriodicAgentCreate
from iblai.models.periodic_agent_log import PeriodicAgentLog
from iblai.models.periodic_agent_log_status_enum import PeriodicAgentLogStatusEnum
from iblai.models.periodic_task import PeriodicTask
from iblai.models.perlearner_course_progress import PerlearnerCourseProgress
from iblai.models.perlearner_course_progress_data import PerlearnerCourseProgressData
from iblai.models.perlearner_engagement_videos_data import PerlearnerEngagementVideosData
from iblai.models.perlearner_engagement_videos_watched_per_course import PerlearnerEngagementVideosWatchedPerCourse
from iblai.models.perlearner_grade_summary import PerlearnerGradeSummary
from iblai.models.perlearner_grade_summary_data import PerlearnerGradeSummaryData
from iblai.models.perlearner_grade_with_cut_off import PerlearnerGradeWithCutOff
from iblai.models.perlearner_grade_with_cut_off_data import PerlearnerGradeWithCutOffData
from iblai.models.perlearner_grading_per_course_api import PerlearnerGradingPerCourseAPI
from iblai.models.perlearner_grading_per_course_api_data import PerlearnerGradingPerCourseAPIData
from iblai.models.perlearner_user_list import PerlearnerUserList
from iblai.models.perlearner_user_list_data import PerlearnerUserListData
from iblai.models.pie_chart_data import PieChartData
from iblai.models.pie_chart_segment import PieChartSegment
from iblai.models.pinned_message_create import PinnedMessageCreate
from iblai.models.pinned_message_get import PinnedMessageGet
from iblai.models.pinned_message_request import PinnedMessageRequest
from iblai.models.platform import Platform
from iblai.models.platform_api_key import PlatformApiKey
from iblai.models.platform_invitation_create import PlatformInvitationCreate
from iblai.models.platform_invitation_detail import PlatformInvitationDetail
from iblai.models.platform_invitation_redemption import PlatformInvitationRedemption
from iblai.models.platform_license_create import PlatformLicenseCreate
from iblai.models.platform_license_detail import PlatformLicenseDetail
from iblai.models.platform_license_update import PlatformLicenseUpdate
from iblai.models.platform_list import PlatformList
from iblai.models.platform_list_status_enum import PlatformListStatusEnum
from iblai.models.platform_public_metadata import PlatformPublicMetadata
from iblai.models.platform_skill_point_bulk_request import PlatformSkillPointBulkRequest
from iblai.models.platform_skill_point_bulk_response import PlatformSkillPointBulkResponse
from iblai.models.platform_skill_point_group_request import PlatformSkillPointGroupRequest
from iblai.models.platform_skill_point_request import PlatformSkillPointRequest
from iblai.models.platform_skill_point_response import PlatformSkillPointResponse
from iblai.models.platform_update_post_request import PlatformUpdatePostRequest
from iblai.models.play_wright_script import PlayWrightScript
from iblai.models.points_percentile import PointsPercentile
from iblai.models.predictive_analytics_request import PredictiveAnalyticsRequest
from iblai.models.predictive_analytics_response import PredictiveAnalyticsResponse
from iblai.models.preview_response import PreviewResponse
from iblai.models.previous_agent_status_enum import PreviousAgentStatusEnum
from iblai.models.product import Product
from iblai.models.product_table import ProductTable
from iblai.models.program import Program
from iblai.models.program_completion_response import ProgramCompletionResponse
from iblai.models.program_course_position import ProgramCoursePosition
from iblai.models.program_create_update_request import ProgramCreateUpdateRequest
from iblai.models.program_delete_response import ProgramDeleteResponse
from iblai.models.program_enrollment import ProgramEnrollment
from iblai.models.program_enrollment_plus import ProgramEnrollmentPlus
from iblai.models.program_enrollment_search_response import ProgramEnrollmentSearchResponse
from iblai.models.program_group_suggestion_create import ProgramGroupSuggestionCreate
from iblai.models.program_group_suggestion_detail import ProgramGroupSuggestionDetail
from iblai.models.program_invitation_create import ProgramInvitationCreate
from iblai.models.program_invitation_detail import ProgramInvitationDetail
from iblai.models.program_invitation_redemption import ProgramInvitationRedemption
from iblai.models.program_license_assignment_create import ProgramLicenseAssignmentCreate
from iblai.models.program_license_assignment_detail import ProgramLicenseAssignmentDetail
from iblai.models.program_license_create_detail import ProgramLicenseCreateDetail
from iblai.models.program_license_detail import ProgramLicenseDetail
from iblai.models.program_license_group_assignment_create import ProgramLicenseGroupAssignmentCreate
from iblai.models.program_license_group_assignment_detail import ProgramLicenseGroupAssignmentDetail
from iblai.models.program_license_update_detail import ProgramLicenseUpdateDetail
from iblai.models.program_metadata_request import ProgramMetadataRequest
from iblai.models.program_metadata_response import ProgramMetadataResponse
from iblai.models.program_review import ProgramReview
from iblai.models.program_review_info_response import ProgramReviewInfoResponse
from iblai.models.program_review_paginated_response import ProgramReviewPaginatedResponse
from iblai.models.program_review_request import ProgramReviewRequest
from iblai.models.program_search import ProgramSearch
from iblai.models.program_suggestion_bulk_create import ProgramSuggestionBulkCreate
from iblai.models.program_suggestion_create import ProgramSuggestionCreate
from iblai.models.program_suggestion_detail import ProgramSuggestionDetail
from iblai.models.program_type_enum import ProgramTypeEnum
from iblai.models.prompt import Prompt
from iblai.models.prompt_category import PromptCategory
from iblai.models.prompt_facet import PromptFacet
from iblai.models.prompt_search_response import PromptSearchResponse
from iblai.models.prompt_visibility_enum import PromptVisibilityEnum
from iblai.models.provider05c_enum import Provider05cEnum
from iblai.models.provider637_enum import Provider637Enum
from iblai.models.provider63a_enum import Provider63aEnum
from iblai.models.provider_association_stripe_callback_retrieve404_response import ProviderAssociationStripeCallbackRetrieve404Response
from iblai.models.question_card_tag import QuestionCardTag
from iblai.models.question_request import QuestionRequest
from iblai.models.question_response import QuestionResponse
from iblai.models.rating_enum import RatingEnum
from iblai.models.rating_record import RatingRecord
from iblai.models.rbac_base_role import RbacBaseRole
from iblai.models.rbac_group import RbacGroup
from iblai.models.rbac_platform import RbacPlatform
from iblai.models.rbac_policy import RbacPolicy
from iblai.models.rbac_policy_group import RbacPolicyGroup
from iblai.models.rbac_role import RbacRole
from iblai.models.rbac_user import RbacUser
from iblai.models.recently_accessed_mentor import RecentlyAccessedMentor
from iblai.models.recipient import Recipient
from iblai.models.recommend_course_block import RecommendCourseBlock
from iblai.models.recommend_course_response import RecommendCourseResponse
from iblai.models.recommendation_search_api import RecommendationSearchAPI
from iblai.models.recommended_courses_response import RecommendedCoursesResponse
from iblai.models.redirect_token_request import RedirectTokenRequest
from iblai.models.redirect_token_response import RedirectTokenResponse
from iblai.models.related_text import RelatedText
from iblai.models.report_create import ReportCreate
from iblai.models.report_data import ReportData
from iblai.models.report_detail import ReportDetail
from iblai.models.report_list import ReportList
from iblai.models.report_request import ReportRequest
from iblai.models.report_status import ReportStatus
from iblai.models.reported_role import ReportedRole
from iblai.models.reported_role_create_update_request import ReportedRoleCreateUpdateRequest
from iblai.models.reported_skill import ReportedSkill
from iblai.models.request_data_variable import RequestDataVariable
from iblai.models.resource import Resource
from iblai.models.resource_completion import ResourceCompletion
from iblai.models.resource_completion_request import ResourceCompletionRequest
from iblai.models.resource_create_update import ResourceCreateUpdate
from iblai.models.resource_delete_response import ResourceDeleteResponse
from iblai.models.resource_point import ResourcePoint
from iblai.models.resource_scrapped_data import ResourceScrappedData
from iblai.models.resource_scrapped_data_status import ResourceScrappedDataStatus
from iblai.models.resource_scrapped_data_status_enum import ResourceScrappedDataStatusEnum
from iblai.models.response_data_variable import ResponseDataVariable
from iblai.models.retreiver_train_view_request import RetreiverTrainViewRequest
from iblai.models.retreiver_train_view_response import RetreiverTrainViewResponse
from iblai.models.retrieve_task import RetrieveTask
from iblai.models.retriever_document_embedding import RetrieverDocumentEmbedding
from iblai.models.retriever_document_embedding_access import RetrieverDocumentEmbeddingAccess
from iblai.models.retriever_document_embedding_request import RetrieverDocumentEmbeddingRequest
from iblai.models.retriever_document_embedding_training_status import RetrieverDocumentEmbeddingTrainingStatus
from iblai.models.retriever_request_search import RetrieverRequestSearch
from iblai.models.retriever_request_search_document import RetrieverRequestSearchDocument
from iblai.models.retriever_response_search import RetrieverResponseSearch
from iblai.models.reuest_data_variable_list import ReuestDataVariableList
from iblai.models.revenue_by_product import RevenueByProduct
from iblai.models.role import Role
from iblai.models.role_create_update_request import RoleCreateUpdateRequest
from iblai.models.run_mentor_eval import RunMentorEval
from iblai.models.scan_webhook_request import ScanWebhookRequest
from iblai.models.scan_webhook_response import ScanWebhookResponse
from iblai.models.section import Section
from iblai.models.section_with_children import SectionWithChildren
from iblai.models.seed_mentors_view import SeedMentorsView
from iblai.models.send_notification import SendNotification
from iblai.models.send_response import SendResponse
from iblai.models.sentiment_summary import SentimentSummary
from iblai.models.session_browser_screenshot import SessionBrowserScreenshot
from iblai.models.session_detail import SessionDetail
from iblai.models.session_memory_storage import SessionMemoryStorage
from iblai.models.shell_logs import ShellLogs
from iblai.models.skill import Skill
from iblai.models.skill_create_update_request import SkillCreateUpdateRequest
from iblai.models.skill_detail import SkillDetail
from iblai.models.skill_info import SkillInfo
from iblai.models.skill_threshold import SkillThreshold
from iblai.models.slack_config import SlackConfig
from iblai.models.slack_user_config import SlackUserConfig
from iblai.models.slack_webhook import SlackWebhook
from iblai.models.spaced_repetition_learning_path import SpacedRepetitionLearningPath
from iblai.models.spaced_repetition_question_stats import SpacedRepetitionQuestionStats
from iblai.models.star_mentor import StarMentor
from iblai.models.state_enum import StateEnum
from iblai.models.status6ee_enum import Status6eeEnum
from iblai.models.step import Step
from iblai.models.step_status_enum import StepStatusEnum
from iblai.models.stripe_billing_page_identifier_response import StripeBillingPageIdentifierResponse
from iblai.models.stripe_checkout_session_request import StripeCheckoutSessionRequest
from iblai.models.stripe_checkout_session_request_mode_enum import StripeCheckoutSessionRequestModeEnum
from iblai.models.stripe_checkout_session_response import StripeCheckoutSessionResponse
from iblai.models.stripe_context import StripeContext
from iblai.models.stripe_customer_portal_request import StripeCustomerPortalRequest
from iblai.models.stripe_customer_portal_response import StripeCustomerPortalResponse
from iblai.models.stripe_local_product import StripeLocalProduct
from iblai.models.stripe_new_user_tenant_launch_request import StripeNewUserTenantLaunchRequest
from iblai.models.stripe_subscription_renewal_request import StripeSubscriptionRenewalRequest
from iblai.models.stripe_subscription_renewal_response import StripeSubscriptionRenewalResponse
from iblai.models.stt_provider_enum import SttProviderEnum
from iblai.models.student_chat_message import StudentChatMessage
from iblai.models.styles_view import StylesView
from iblai.models.sub_section import SubSection
from iblai.models.sub_section_with_children import SubSectionWithChildren
from iblai.models.sub_time_child import SubTimeChild
from iblai.models.summary import Summary
from iblai.models.tags_view import TagsView
from iblai.models.target_system_enum import TargetSystemEnum
from iblai.models.task_view import TaskView
from iblai.models.teams_config import TeamsConfig
from iblai.models.teams_webhook import TeamsWebhook
from iblai.models.template_mentor import TemplateMentor
from iblai.models.tenant_launch_error import TenantLaunchError
from iblai.models.tenant_launch_failed import TenantLaunchFailed
from iblai.models.tenant_launch_request import TenantLaunchRequest
from iblai.models.tenant_launch_response import TenantLaunchResponse
from iblai.models.tenant_mentor_traces import TenantMentorTraces
from iblai.models.theme_enum import ThemeEnum
from iblai.models.time_child_data import TimeChildData
from iblai.models.time_detail import TimeDetail
from iblai.models.time_detail_child import TimeDetailChild
from iblai.models.time_detail_data import TimeDetailData
from iblai.models.time_spent_by_users_in_course import TimeSpentByUsersInCourse
from iblai.models.time_spent_by_users_in_course_data import TimeSpentByUsersInCourseData
from iblai.models.time_spent_per_course import TimeSpentPerCourse
from iblai.models.time_spent_per_course_data import TimeSpentPerCourseData
from iblai.models.time_spent_per_user_response import TimeSpentPerUserResponse
from iblai.models.time_spent_update_request import TimeSpentUpdateRequest
from iblai.models.time_spent_update_response import TimeSpentUpdateResponse
from iblai.models.token_proxy_input import TokenProxyInput
from iblai.models.token_proxy_output import TokenProxyOutput
from iblai.models.token_proxy_output_serializer_data import TokenProxyOutputSerializerData
from iblai.models.token_proxy_user import TokenProxyUser
from iblai.models.tones_view import TonesView
from iblai.models.tool_response import ToolResponse
from iblai.models.topic_model import TopicModel
from iblai.models.topic_record import TopicRecord
from iblai.models.topic_statistics import TopicStatistics
from iblai.models.topic_statistics_response import TopicStatisticsResponse
from iblai.models.topic_summary_view import TopicSummaryView
from iblai.models.train_chat_session_document_view import TrainChatSessionDocumentView
from iblai.models.train_chat_session_document_view_request import TrainChatSessionDocumentViewRequest
from iblai.models.train_document_view_request import TrainDocumentViewRequest
from iblai.models.train_document_view_response import TrainDocumentViewResponse
from iblai.models.training import Training
from iblai.models.training_create import TrainingCreate
from iblai.models.training_status_enum import TrainingStatusEnum
from iblai.models.transport_enum import TransportEnum
from iblai.models.trend_entry import TrendEntry
from iblai.models.trigger_request import TriggerRequest
from iblai.models.trigger_response import TriggerResponse
from iblai.models.tts_provider_enum import TtsProviderEnum
from iblai.models.type_c42_enum import TypeC42Enum
from iblai.models.unit import Unit
from iblai.models.unit_with_children import UnitWithChildren
from iblai.models.uploaded_image import UploadedImage
from iblai.models.use_main_creds import UseMainCreds
from iblai.models.user_all_chat_memory_view import UserAllChatMemoryView
from iblai.models.user_app import UserApp
from iblai.models.user_catalog_item_memory_view import UserCatalogItemMemoryView
from iblai.models.user_chat_by_period import UserChatByPeriod
from iblai.models.user_chat_feedback import UserChatFeedback
from iblai.models.user_chat_feedback_count import UserChatFeedbackCount
from iblai.models.user_chat_memory_status_request_view import UserChatMemoryStatusRequestView
from iblai.models.user_chat_memory_status_view import UserChatMemoryStatusView
from iblai.models.user_chat_memory_update_view import UserChatMemoryUpdateView
from iblai.models.user_count_record import UserCountRecord
from iblai.models.user_delete_api_error import UserDeleteAPIError
from iblai.models.user_delete_api_request import UserDeleteAPIRequest
from iblai.models.user_delete_api_response import UserDeleteAPIResponse
from iblai.models.user_edx_memory import UserEdxMemory
from iblai.models.user_info import UserInfo
from iblai.models.user_license_assignment_create import UserLicenseAssignmentCreate
from iblai.models.user_license_assignment_detail import UserLicenseAssignmentDetail
from iblai.models.user_license_create import UserLicenseCreate
from iblai.models.user_license_detail import UserLicenseDetail
from iblai.models.user_license_group_assignment_create import UserLicenseGroupAssignmentCreate
from iblai.models.user_license_group_assignment_detail import UserLicenseGroupAssignmentDetail
from iblai.models.user_license_update import UserLicenseUpdate
from iblai.models.user_memory_context_request import UserMemoryContextRequest
from iblai.models.user_memory_context_response import UserMemoryContextResponse
from iblai.models.user_metric import UserMetric
from iblai.models.user_metrics_response import UserMetricsResponse
from iblai.models.user_platform_link import UserPlatformLink
from iblai.models.user_platform_management_list_view_get_response import UserPlatformManagementListViewGetResponse
from iblai.models.user_platform_view_post_request import UserPlatformViewPostRequest
from iblai.models.user_proxy_bulk_request import UserProxyBulkRequest
from iblai.models.user_proxy_get_response import UserProxyGetResponse
from iblai.models.user_proxy_post_request import UserProxyPostRequest
from iblai.models.user_proxy_post_response import UserProxyPostResponse
from iblai.models.user_search_response import UserSearchResponse
from iblai.models.user_search_view_get_response import UserSearchViewGetResponse
from iblai.models.user_sentiment_count_view import UserSentimentCountView
from iblai.models.user_skill import UserSkill
from iblai.models.user_skill_points_percentile import UserSkillPointsPercentile
from iblai.models.user_trend_by_period import UserTrendByPeriod
from iblai.models.validate_source_response import ValidateSourceResponse
from iblai.models.value import Value
from iblai.models.value_data import ValueData
from iblai.models.vector_result import VectorResult
from iblai.models.verify_gcp_market_place_failed_response import VerifyGCPMarketPlaceFailedResponse
from iblai.models.verify_gcp_market_place_request import VerifyGCPMarketPlaceRequest
from iblai.models.verify_gcp_market_place_response import VerifyGCPMarketPlaceResponse
from iblai.models.video_block import VideoBlock
from iblai.models.video_caption import VideoCaption
from iblai.models.video_engagement_per_course import VideoEngagementPerCourse
from iblai.models.video_engagement_per_course_data import VideoEngagementPerCourseData
from iblai.models.videos_count import VideosCount
from iblai.models.videos_count_data import VideosCountData
from iblai.models.videos_in_course_summary import VideosInCourseSummary
from iblai.models.videos_in_course_summary_data import VideosInCourseSummaryData
from iblai.models.videos_specific_course import VideosSpecificCourse
from iblai.models.videos_specific_course_data import VideosSpecificCourseData
from iblai.models.videos_watched_sub_section import VideosWatchedSubSection
from iblai.models.voice import Voice
from iblai.models.watched_videos_per_course import WatchedVideosPerCourse
from iblai.models.watched_videos_per_course_data import WatchedVideosPerCourseData
from iblai.models.watched_videos_per_user import WatchedVideosPerUser
from iblai.models.watched_videos_per_user_data import WatchedVideosPerUserData
from iblai.models.web_resource import WebResource
from iblai.models.web_resource_card import WebResourceCard
from iblai.models.web_resources_query import WebResourcesQuery
from iblai.models.webex_config import WebexConfig
from iblai.models.webex_webhook import WebexWebhook
from iblai.models.what_app_web_hook import WhatAppWebHook
from iblai.models.whatsapp_config import WhatsappConfig
from iblai.models.whatsapp_user_config import WhatsappUserConfig
from iblai.models.whitelisted_domain import WhitelistedDomain



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.topic import Topic

class TestTopic(unittest.TestCase):
    """Topic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Topic:
        """Test Topic
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Topic`
        """
        model = Topic()
        if include_optional:
            return Topic(
                total_topics = 56,
                number_of_messages = 56,
                topic_detail = [
                    iblai.models.topic_detail.TopicDetail(
                        id = 56, 
                        total_topics = 56, 
                        number_of_messages = 56, 
                        number_of_conversations = 56, 
                        user_sentiment = '', 
                        user_ratings = '', 
                        name = '', 
                        metadata = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        platform = 56, )
                    ],
                monthly_total_topics_diff = 56
            )
        else:
            return Topic(
                total_topics = 56,
                number_of_messages = 56,
                topic_detail = [
                    iblai.models.topic_detail.TopicDetail(
                        id = 56, 
                        total_topics = 56, 
                        number_of_messages = 56, 
                        number_of_conversations = 56, 
                        user_sentiment = '', 
                        user_ratings = '', 
                        name = '', 
                        metadata = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        platform = 56, )
                    ],
                monthly_total_topics_diff = 56,
        )
        """

    def testTopic(self):
        """Test Topic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from iblai.api.media_resources_api import MediaResourcesApi
from iblai.api.ai_account_api import AiAccountApi
from iblai.api.ai_analytics_api import AiAnalyticsApi
from iblai.api.ai_bot_api import AiBotApi
from iblai.api.ai_finetuning_api import AiFinetuningApi
from iblai.api.ai_index_api import AiIndexApi
from iblai.api.ai_marketing_api import AiMarketingApi
from iblai.api.ai_media_api import AiMediaApi
from iblai.api.ai_mentor_api import AiMentorApi
from iblai.api.ai_prompt_api import AiPromptApi
from iblai.api.analytics_api import AnalyticsApi
from iblai.api.audience_api import AudienceApi
from iblai.api.career_api import CareerApi
from iblai.api.catalog_api import CatalogApi
from iblai.api.core_api import CoreApi
from iblai.api.credentials_api import CredentialsApi
from iblai.api.departments_api import DepartmentsApi
from iblai.api.engagement_api import EngagementApi
from iblai.api.features_api import FeaturesApi
from iblai.api.finance_api import FinanceApi
from iblai.api.notification_api import NotificationApi
from iblai.api.notification_builder_api import NotificationBuilderApi
from iblai.api.orgs_api import OrgsApi
from iblai.api.overview_api import OverviewApi
from iblai.api.performance_api import PerformanceApi
from iblai.api.perlearner_api import PerlearnerApi
from iblai.api.platform_api import PlatformApi
from iblai.api.provider_association_api import ProviderAssociationApi
from iblai.api.providers_api import ProvidersApi
from iblai.api.provision_api import ProvisionApi
from iblai.api.recommendations_api import RecommendationsApi
from iblai.api.reports_api import ReportsApi
from iblai.api.roles_api import RolesApi
from iblai.api.search_api import SearchApi
from iblai.api.service_api import ServiceApi
from iblai.api.skills_api import SkillsApi
from iblai.api.user_groups_api import UserGroupsApi




# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class NewPerLearnerListData(BaseModel):
    """
    NewPerLearnerListData
    """ # noqa: E501
    username: StrictStr
    user_id: StrictInt
    name: StrictStr
    email: StrictStr
    courses_enrolled: StrictInt
    courses_completed: StrictInt
    time_spent: StrictStr
    pathways_assigned: StrictInt
    pathways_completed: StrictInt
    certificates_earned: StrictInt
    assessments_passed: StrictInt
    skills_earned: StrictInt
    skills_points: StrictInt
    last_login: StrictStr
    location: StrictStr
    __properties: ClassVar[List[str]] = ["username", "user_id", "name", "email", "courses_enrolled", "courses_completed", "time_spent", "pathways_assigned", "pathways_completed", "certificates_earned", "assessments_passed", "skills_earned", "skills_points", "last_login", "location"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NewPerLearnerListData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NewPerLearnerListData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "username": obj.get("username"),
            "user_id": obj.get("user_id"),
            "name": obj.get("name"),
            "email": obj.get("email"),
            "courses_enrolled": obj.get("courses_enrolled"),
            "courses_completed": obj.get("courses_completed"),
            "time_spent": obj.get("time_spent"),
            "pathways_assigned": obj.get("pathways_assigned"),
            "pathways_completed": obj.get("pathways_completed"),
            "certificates_earned": obj.get("certificates_earned"),
            "assessments_passed": obj.get("assessments_passed"),
            "skills_earned": obj.get("skills_earned"),
            "skills_points": obj.get("skills_points"),
            "last_login": obj.get("last_login"),
            "location": obj.get("location")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.notification_preview import NotificationPreview

class TestNotificationPreview(unittest.TestCase):
    """NotificationPreview unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NotificationPreview:
        """Test NotificationPreview
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotificationPreview`
        """
        model = NotificationPreview()
        if include_optional:
            return NotificationPreview(
                template_id = '',
                template_data = iblai.models.notification_template_data.NotificationTemplateData(
                    message_title = '', 
                    message_body = '', ),
                channels = [
                    56
                    ],
                sources = [
                    iblai.models.notification_source.NotificationSource(
                        type = 'email', 
                        data = null, )
                    ],
                context = {
                    'key' : null
                    },
                process_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return NotificationPreview(
                channels = [
                    56
                    ],
                sources = [
                    iblai.models.notification_source.NotificationSource(
                        type = 'email', 
                        data = null, )
                    ],
        )
        """

    def testNotificationPreview(self):
        """Test NotificationPreview"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from iblai.models.rbac_platform import RbacPlatform
from iblai.models.rbac_user import RbacUser
from typing import Optional, Set
from typing_extensions import Self

class RbacGroup(BaseModel):
    """
    Serializer for RBAC groups.
    """ # noqa: E501
    id: StrictInt
    unique_id: Annotated[str, Field(strict=True, max_length=255)] = Field(description="The unique identifier for the group")
    platform: RbacPlatform
    platform_key: StrictStr = Field(description="The platform key")
    name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Optional name of the group")
    description: Optional[StrictStr] = Field(default=None, description="Optional group description")
    users: List[RbacUser]
    users_to_add: Optional[List[StrictInt]] = Field(default=None, description="List of user IDs to add to this group")
    users_to_remove: Optional[List[StrictInt]] = Field(default=None, description="List of user IDs to remove from this group")
    __properties: ClassVar[List[str]] = ["id", "unique_id", "platform", "platform_key", "name", "description", "users", "users_to_add", "users_to_remove"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RbacGroup from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "platform",
            "users",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of platform
        if self.platform:
            _dict['platform'] = self.platform.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in users (list)
        _items = []
        if self.users:
            for _item in self.users:
                if _item:
                    _items.append(_item.to_dict())
            _dict['users'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RbacGroup from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "unique_id": obj.get("unique_id"),
            "platform": RbacPlatform.from_dict(obj["platform"]) if obj.get("platform") is not None else None,
            "platform_key": obj.get("platform_key"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "users": [RbacUser.from_dict(_item) for _item in obj["users"]] if obj.get("users") is not None else None,
            "users_to_add": obj.get("users_to_add"),
            "users_to_remove": obj.get("users_to_remove")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictStr
from typing import Optional
from iblai.models.report_create import ReportCreate
from iblai.models.report_detail import ReportDetail
from iblai.models.report_list import ReportList
from iblai.models.report_request import ReportRequest

from iblai.api_client import ApiClient, RequestSerialized
from iblai.api_response import ApiResponse
from iblai.rest import RESTResponseType


class ReportsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def reports_orgs_new_create(
        self,
        org: StrictStr,
        report_request: Optional[ReportRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """reports_orgs_new_create

        Creates and manages report generation requests.  This endpoint allows users to: 1. Request a new report generation 2. Check the status of a previously requested report 3. Force regeneration of an existing report  Reports expire after a configured time period (default is typically 24-48 hours).  Request Parameters:     report_name (str): The identifier of the report to generate     owner (str): The username of the report owner (usually the current user)     learner_id (str, optional): Filter by specific learner     course_id (str, optional): Filter by specific course     start_date (str, optional): Start date for report data (ISO format)     end_date (str, optional): End date for report data (ISO format)     filters (dict, optional): Additional filters specific to the report type     force (bool, optional): Force regeneration even if a valid report exists  Returns:     For new reports:         - report_id: The unique identifier for the report task         - state: The current state of the report (PENDING, RUNNING, etc.)      For completed reports:         - report_id: The unique identifier for the report task         - report_name: The name of the report         - url: Download URL for the report         - state: COMPLETED         - expires: Expiration timestamp for the report      For in-progress reports:         - report_id: The unique identifier for the report task         - state: Current state (PENDING, RUNNING)         - started_on: When the report generation started         - owner: Username of the report owner  Error Responses:     400 Bad Request: Invalid parameters or report configuration     404 Not Found: Report type not found     403 Forbidden: User doesn't have permission for the requested report

        :param org: (required)
        :type org: str
        :param report_request:
        :type report_request: ReportRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reports_orgs_new_create_serialize(
            org=org,
            report_request=report_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportCreate",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _reports_orgs_new_create_serialize(
        self,
        org,
        report_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if report_request is not None:
            _body_params = report_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/reports/orgs/{org}/new',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def reports_orgs_retrieve(
        self,
        org: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """reports_orgs_retrieve

        Lists all available reports in the system.  This endpoint returns a list of all reports available to the user, including: - Report metadata (name, description, icon) - Available query parameters for each report - Result columns that will be returned - Current status of any previously requested reports  If a report has been previously requested by the user, its status will be included in the response. Expired reports are automatically cleaned up.  Returns:     A list of report objects with their metadata and status information.

        :param org: (required)
        :type org: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reports_orgs_retrieve_serialize(
            org=org,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _reports_orgs_retrieve_serialize(
        self,
        org,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/reports/orgs/{org}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def reports_orgs_retrieve2(
        self,
        org: StrictStr,
        report_name: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """reports_orgs_retrieve2

        Retrieves detailed information about a specific report type.  This endpoint provides: - Metadata about the report (name, description, icon) - Available query parameters for the report - Result columns that will be returned - Current status of the most recent report of this type requested by the user  Path Parameters:     report_name (str): The identifier of the report to retrieve details for  Returns:     Detailed information about the report type and its current status if previously requested.  Error Responses:     404 Not Found: If the specified report type doesn't exist

        :param org: (required)
        :type org: str
        :param report_name: (required)
        :type report_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reports_orgs_retrieve2_serialize(
            org=org,
            report_name=report_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportDetail",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _reports_orgs_retrieve2_serialize(
        self,
        org,
        report_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if report_name is not None:
            _path_params['report_name'] = report_name
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/reports/orgs/{org}/{report_name}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def reports_platforms_new_create(
        self,
        key: StrictStr,
        report_request: Optional[ReportRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """reports_platforms_new_create

        Triggers a new report generation.  If the report has been previously requested, it returns the status of the report. Reports expire after a configured duration.  The request body should include: - report_name: Name of the report to generate - learner_id: (optional) ID of the learner to filter by - course_id: (optional) ID of the course to filter by - force: (optional) Force generation of a new report even if one exists - filters: (optional) Additional filters for the report - departments: (optional) Department IDs to filter by

        :param key: (required)
        :type key: str
        :param report_request:
        :type report_request: ReportRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reports_platforms_new_create_serialize(
            key=key,
            report_request=report_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportCreate",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _reports_platforms_new_create_serialize(
        self,
        key,
        report_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if key is not None:
            _path_params['key'] = key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if report_request is not None:
            _body_params = report_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/reports/platforms/{key}/new',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def reports_platforms_retrieve(
        self,
        key: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """reports_platforms_retrieve

        Returns a list of reports available in the system.  For each report, it includes: - display_name: Human-readable name of the report - description: Description of what the report contains - icon: URL to an icon representing the report - report_name: Unique identifier for the report - extra_query_params: Additional parameters that can be passed when creating the report - result_columns: Columns that will be included in the report results - status: Current status of the report if it has been previously requested  The status will include details like the report ID, state, and download URL if completed.

        :param key: (required)
        :type key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reports_platforms_retrieve_serialize(
            key=key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _reports_platforms_retrieve_serialize(
        self,
        key,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if key is not None:
            _path_params['key'] = key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/reports/platforms/{key}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def reports_platforms_retrieve2(
        self,
        key: StrictStr,
        report_name: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """reports_platforms_retrieve2

        Returns details of a specific report type including its status if previously requested.

        :param key: (required)
        :type key: str
        :param report_name: (required)
        :type report_name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reports_platforms_retrieve2_serialize(
            key=key,
            report_name=report_name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportDetail",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _reports_platforms_retrieve2_serialize(
        self,
        key,
        report_name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if key is not None:
            _path_params['key'] = key
        if report_name is not None:
            _path_params['report_name'] = report_name
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/reports/platforms/{key}/{report_name}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from iblai.models.average import Average
from iblai.models.course_completion_summary_overtime import CourseCompletionSummaryOvertime
from iblai.models.overtime_with_change_info import OvertimeWithChangeInfo
from iblai.models.perlearner_user_list import PerlearnerUserList
from iblai.models.time_spent_per_course import TimeSpentPerCourse

from iblai.api_client import ApiClient, RequestSerialized
from iblai.api_response import ApiResponse
from iblai.rest import RESTResponseType


class OverviewApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def overview_orgs_active_users_retrieve(
        self,
        org: StrictStr,
        department_id: Annotated[Optional[StrictInt], Field(description="When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department ")] = None,
        end_date: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="end date. ISO 8601")] = None,
        format: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="Format  * `json` - json")] = None,
        include_main_platform: Annotated[Optional[StrictBool], Field(description="Include main platform data")] = None,
        start_date: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="start date. ISO 8601")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """overview_orgs_active_users_retrieve

        Get active user counts over time.  This endpoint provides daily counts of active users (users with known activity) over a specified time period.  Query Parameters:     start_date (str, optional): Start date for the time range (ISO format)     end_date (str, optional): End date for the time range (ISO format)  Returns:     Daily active user counts over the specified time period, with change metrics     compared to previous periods.  Default time range is the last 7 days if no dates are specified.  An active user is defined as a user with any activity within the past 30 days.

        :param org: (required)
        :type org: str
        :param department_id: When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department 
        :type department_id: int
        :param end_date: end date. ISO 8601
        :type end_date: str
        :param format: Format  * `json` - json
        :type format: str
        :param include_main_platform: Include main platform data
        :type include_main_platform: bool
        :param start_date: start date. ISO 8601
        :type start_date: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._overview_orgs_active_users_retrieve_serialize(
            org=org,
            department_id=department_id,
            end_date=end_date,
            format=format,
            include_main_platform=include_main_platform,
            start_date=start_date,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OvertimeWithChangeInfo",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _overview_orgs_active_users_retrieve_serialize(
        self,
        org,
        department_id,
        end_date,
        format,
        include_main_platform,
        start_date,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        if department_id is not None:
            
            _query_params.append(('department_id', department_id))
            
        if end_date is not None:
            
            _query_params.append(('end_date', end_date))
            
        if format is not None:
            
            _query_params.append(('format', format))
            
        if include_main_platform is not None:
            
            _query_params.append(('include_main_platform', include_main_platform))
            
        if start_date is not None:
            
            _query_params.append(('start_date', start_date))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/overview/orgs/{org}/active-users',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def overview_orgs_average_grade_retrieve(
        self,
        org: StrictStr,
        department_id: Annotated[Optional[StrictInt], Field(description="When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department ")] = None,
        format: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="Format  * `json` - json")] = None,
        include_main_platform: Annotated[Optional[StrictBool], Field(description="Include main platform data")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """overview_orgs_average_grade_retrieve

        Get average grade value for platform, course, or user.  This endpoint returns the average grade at different levels: - Platform level: Average grade across all courses - Course level: Average grade for a specific course - Learner level: Average grade for a specific learner - Course-learner level: Grade for a specific learner in a specific course  Query Parameters:     course_id (str, optional): Filter by course ID     learner_id (str, optional): Filter by username or email  Returns:     The average grade value based on the specified filters.  Access Control:     - Platform admins can access any grade data     - Learners can access their own grade data

        :param org: (required)
        :type org: str
        :param department_id: When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department 
        :type department_id: int
        :param format: Format  * `json` - json
        :type format: str
        :param include_main_platform: Include main platform data
        :type include_main_platform: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._overview_orgs_average_grade_retrieve_serialize(
            org=org,
            department_id=department_id,
            format=format,
            include_main_platform=include_main_platform,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Average",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _overview_orgs_average_grade_retrieve_serialize(
        self,
        org,
        department_id,
        format,
        include_main_platform,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        if department_id is not None:
            
            _query_params.append(('department_id', department_id))
            
        if format is not None:
            
            _query_params.append(('format', format))
            
        if include_main_platform is not None:
            
            _query_params.append(('include_main_platform', include_main_platform))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/overview/orgs/{org}/average-grade',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def overview_orgs_courses_completions_retrieve(
        self,
        org: StrictStr,
        department_id: Annotated[Optional[StrictInt], Field(description="When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department ")] = None,
        end_date: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="end date. ISO 8601")] = None,
        format: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="Format  * `json` - json")] = None,
        include_main_platform: Annotated[Optional[StrictBool], Field(description="Include main platform data")] = None,
        start_date: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="start date. ISO 8601")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """overview_orgs_courses_completions_retrieve

        Get course completion summary metrics over time.  This endpoint provides completion statistics across the platform over a specified time period, including daily completion counts and overall metrics.  Query Parameters:     start_date (str): Start date for the time range (ISO format)     end_date (str): End date for the time range (ISO format)  Returns:     Completion data including:     - Daily completion counts over time     - Total unique user count     - Total completion count     - Completion percentage     - Change metrics compared to previous periods  Default time range is the last 7 days if no dates are specified.

        :param org: (required)
        :type org: str
        :param department_id: When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department 
        :type department_id: int
        :param end_date: end date. ISO 8601
        :type end_date: str
        :param format: Format  * `json` - json
        :type format: str
        :param include_main_platform: Include main platform data
        :type include_main_platform: bool
        :param start_date: start date. ISO 8601
        :type start_date: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._overview_orgs_courses_completions_retrieve_serialize(
            org=org,
            department_id=department_id,
            end_date=end_date,
            format=format,
            include_main_platform=include_main_platform,
            start_date=start_date,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CourseCompletionSummaryOvertime",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _overview_orgs_courses_completions_retrieve_serialize(
        self,
        org,
        department_id,
        end_date,
        format,
        include_main_platform,
        start_date,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        if department_id is not None:
            
            _query_params.append(('department_id', department_id))
            
        if end_date is not None:
            
            _query_params.append(('end_date', end_date))
            
        if format is not None:
            
            _query_params.append(('format', format))
            
        if include_main_platform is not None:
            
            _query_params.append(('include_main_platform', include_main_platform))
            
        if start_date is not None:
            
            _query_params.append(('start_date', start_date))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/overview/orgs/{org}/courses/completions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def overview_orgs_learners_retrieve(
        self,
        org: StrictStr,
        department_id: Annotated[Optional[StrictInt], Field(description="When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department ")] = None,
        format: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="Format  * `json` - json")] = None,
        include_main_platform: Annotated[Optional[StrictBool], Field(description="Include main platform data")] = None,
        length: Annotated[Optional[StrictInt], Field(description="Size of data to return")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Page offset")] = None,
        search: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="Search string for learner")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """overview_orgs_learners_retrieve

        List all learners on the platform with aggregated metrics.  This endpoint returns a paginated list of all learners with key metrics including: - Enrollment counts - Completion counts - Time spent on platform  Query Parameters:     page (int): Page number for pagination     length (int): Number of items per page     search (str): Filter learners by username, email, or name  Returns:     A paginated list of learners with their associated metrics.

        :param org: (required)
        :type org: str
        :param department_id: When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department 
        :type department_id: int
        :param format: Format  * `json` - json
        :type format: str
        :param include_main_platform: Include main platform data
        :type include_main_platform: bool
        :param length: Size of data to return
        :type length: int
        :param page: Page offset
        :type page: int
        :param search: Search string for learner
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._overview_orgs_learners_retrieve_serialize(
            org=org,
            department_id=department_id,
            format=format,
            include_main_platform=include_main_platform,
            length=length,
            page=page,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PerlearnerUserList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _overview_orgs_learners_retrieve_serialize(
        self,
        org,
        department_id,
        format,
        include_main_platform,
        length,
        page,
        search,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        if department_id is not None:
            
            _query_params.append(('department_id', department_id))
            
        if format is not None:
            
            _query_params.append(('format', format))
            
        if include_main_platform is not None:
            
            _query_params.append(('include_main_platform', include_main_platform))
            
        if length is not None:
            
            _query_params.append(('length', length))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/overview/orgs/{org}/learners',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def overview_orgs_most_active_courses_retrieve(
        self,
        org: StrictStr,
        department_id: Annotated[Optional[StrictInt], Field(description="When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department ")] = None,
        end_date: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="end date. ISO 8601")] = None,
        format: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="Format  * `json` - json")] = None,
        include_main_platform: Annotated[Optional[StrictBool], Field(description="Include main platform data")] = None,
        length: Annotated[Optional[StrictInt], Field(description="Size of data to return")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Page offset")] = None,
        start_date: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="start date. ISO 8601")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """overview_orgs_most_active_courses_retrieve

        Get time spent statistics on a per-course basis.  This endpoint provides a paginated list of courses with the total time spent by users in each course.  Query Parameters:     start_date (str, optional): Start date for filtering (ISO format)     end_date (str, optional): End date for filtering (ISO format)     page (int, optional): Page number for pagination     length (int, optional): Number of items per page  Returns:     A paginated list of courses with:     - Course identification (ID and name)     - Total time spent (in seconds)     - Formatted time spent (human-readable)     - Percentage of total platform time

        :param org: (required)
        :type org: str
        :param department_id: When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department 
        :type department_id: int
        :param end_date: end date. ISO 8601
        :type end_date: str
        :param format: Format  * `json` - json
        :type format: str
        :param include_main_platform: Include main platform data
        :type include_main_platform: bool
        :param length: Size of data to return
        :type length: int
        :param page: Page offset
        :type page: int
        :param start_date: start date. ISO 8601
        :type start_date: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._overview_orgs_most_active_courses_retrieve_serialize(
            org=org,
            department_id=department_id,
            end_date=end_date,
            format=format,
            include_main_platform=include_main_platform,
            length=length,
            page=page,
            start_date=start_date,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TimeSpentPerCourse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _overview_orgs_most_active_courses_retrieve_serialize(
        self,
        org,
        department_id,
        end_date,
        format,
        include_main_platform,
        length,
        page,
        start_date,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        if department_id is not None:
            
            _query_params.append(('department_id', department_id))
            
        if end_date is not None:
            
            _query_params.append(('end_date', end_date))
            
        if format is not None:
            
            _query_params.append(('format', format))
            
        if include_main_platform is not None:
            
            _query_params.append(('include_main_platform', include_main_platform))
            
        if length is not None:
            
            _query_params.append(('length', length))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if start_date is not None:
            
            _query_params.append(('start_date', start_date))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/overview/orgs/{org}/most-active-courses',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def overview_orgs_registered_users_retrieve(
        self,
        org: StrictStr,
        department_id: Annotated[Optional[StrictInt], Field(description="When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department ")] = None,
        end_date: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="end date. ISO 8601")] = None,
        format: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="Format  * `json` - json")] = None,
        include_main_platform: Annotated[Optional[StrictBool], Field(description="Include main platform data")] = None,
        start_date: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="start date. ISO 8601")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """overview_orgs_registered_users_retrieve

        Get registered user counts over time.  This endpoint provides daily counts of new user registrations over a specified time period.  Query Parameters:     start_date (str, optional): Start date for the time range (ISO format)     end_date (str, optional): End date for the time range (ISO format)  Returns:     Daily registration counts over the specified time period, with change metrics     compared to previous periods.  Default time range is the last 7 days if no dates are specified.

        :param org: (required)
        :type org: str
        :param department_id: When `department_mode=1` is passed, it allows to filter data for only user content groups for the specified department 
        :type department_id: int
        :param end_date: end date. ISO 8601
        :type end_date: str
        :param format: Format  * `json` - json
        :type format: str
        :param include_main_platform: Include main platform data
        :type include_main_platform: bool
        :param start_date: start date. ISO 8601
        :type start_date: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._overview_orgs_registered_users_retrieve_serialize(
            org=org,
            department_id=department_id,
            end_date=end_date,
            format=format,
            include_main_platform=include_main_platform,
            start_date=start_date,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OvertimeWithChangeInfo",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _overview_orgs_registered_users_retrieve_serialize(
        self,
        org,
        department_id,
        end_date,
        format,
        include_main_platform,
        start_date,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        if department_id is not None:
            
            _query_params.append(('department_id', department_id))
            
        if end_date is not None:
            
            _query_params.append(('end_date', end_date))
            
        if format is not None:
            
            _query_params.append(('format', format))
            
        if include_main_platform is not None:
            
            _query_params.append(('include_main_platform', include_main_platform))
            
        if start_date is not None:
            
            _query_params.append(('start_date', start_date))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/overview/orgs/{org}/registered-users',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from iblai.models.stripe_checkout_session_request_mode_enum import StripeCheckoutSessionRequestModeEnum
from typing import Optional, Set
from typing_extensions import Self

class StripeCheckoutSessionRequest(BaseModel):
    """
    Serializer for Stripe checkout session creation requests.
    """ # noqa: E501
    sku: Optional[StrictStr] = Field(default=None, description="Product SKU")
    product: Optional[StrictStr] = Field(default=None, description="Alternative to SKU")
    success_url: StrictStr = Field(description="URL to redirect after successful payment")
    cancel_url: StrictStr = Field(description="URL to redirect if checkout cancelled")
    mode: Optional[StripeCheckoutSessionRequestModeEnum] = Field(default=None, description="Checkout mode  * `subscription` - subscription * `payment` - payment * `setup` - setup")
    metered: Optional[StrictBool] = Field(default=False, description="Whether to use metered billing")
    quantity: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=1, description="Subscription quantity")
    coupon: Optional[StrictStr] = Field(default=None, description="Coupon code to apply")
    is_free_trial: Optional[StrictBool] = Field(default=False, description="Enable free trial")
    trial_days: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Trial period in days")
    skip_card: Optional[StrictBool] = Field(default=False, description="Skip card collection for trial")
    __properties: ClassVar[List[str]] = ["sku", "product", "success_url", "cancel_url", "mode", "metered", "quantity", "coupon", "is_free_trial", "trial_days", "skip_card"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StripeCheckoutSessionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StripeCheckoutSessionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "sku": obj.get("sku"),
            "product": obj.get("product"),
            "success_url": obj.get("success_url"),
            "cancel_url": obj.get("cancel_url"),
            "mode": obj.get("mode"),
            "metered": obj.get("metered") if obj.get("metered") is not None else False,
            "quantity": obj.get("quantity") if obj.get("quantity") is not None else 1,
            "coupon": obj.get("coupon"),
            "is_free_trial": obj.get("is_free_trial") if obj.get("is_free_trial") is not None else False,
            "trial_days": obj.get("trial_days"),
            "skip_card": obj.get("skip_card") if obj.get("skip_card") is not None else False
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.time_detail_data import TimeDetailData

class TestTimeDetailData(unittest.TestCase):
    """TimeDetailData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TimeDetailData:
        """Test TimeDetailData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TimeDetailData`
        """
        model = TimeDetailData()
        if include_optional:
            return TimeDetailData(
                average_time = 1.337,
                display_name = '',
                id = '',
                children = [
                    iblai.models.time_detail_child.TimeDetailChild(
                        average_time = 1.337, 
                        display_name = '', 
                        id = '', 
                        block_id = '', 
                        total_time = 56, 
                        total_users = 56, )
                    ],
                total_time = 56,
                total_users = 56
            )
        else:
            return TimeDetailData(
                average_time = 1.337,
                display_name = '',
                id = '',
        )
        """

    def testTimeDetailData(self):
        """Test TimeDetailData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
